@@ -5,8 +5,9 @@ use Exporter qw(import);
 
 use IO::Interactive qw(is_interactive);
 use IO::Prompt      qw();                 # don't import prompt
+use Term::ReadKey;
 
-our $VERSION = version->declare("v2.19.8");
+our $VERSION = version->declare("v2.19.10");
 
 our %EXPORT_TAGS = (
                      misc => [ qw(
@@ -32,7 +33,7 @@ sub banner {
 
     my $width;
     if ( is_interactive() ) {
-        ($width) = GetTerminalSize();
+        ($width) = Term::ReadKey::GetTerminalSize();
     }
     else {
         $width = 80;
@@ -85,14 +86,15 @@ sub yes_no_prompt {
     $msg .= $ynd;
     $msg .= $settings->{ append };
 
-    return
-        IO::Prompt::prompt(
-                            -prompt => $msg,
-                            -onechar,
-                            -default => ( $settings->{ default } ) ? 'Y' : 'N',
-                            -yes_no,
-                            -require => { "Please choose${ynd}: " => qr/[YN]/i }
-                          );
+    my $response
+        = IO::Prompt::prompt(
+                              -prompt => $msg,
+                              -onechar,
+                              -default => ( $settings->{ default } ) ? 'Y' : 'N',
+                              -yes_no,
+                              -require => { "Please choose${ynd}: " => qr/[YN]/i }
+                            );
+    return $response->{ value };
 }
 
 sub prompt {
@@ -144,7 +146,7 @@ Dev::Util::Query - Functions to prompt user for input, y/n, or menus.
 
 =head1 VERSION
 
-Version v2.19.8
+Version v2.19.10
 
 =head1 SYNOPSIS
 
@@ -240,16 +242,16 @@ C<APPEND> Text to append to TEXT
 
 =head2 B<prompt(ARGS_HASH)>
 
-Prompt user for input. 
+Prompt user for input.
 
 B<ARGS_HASH:>
 { text => TEXT, default => DEFAULT, valid => VALID, prepend => PREPEND, append => APPEND, noecho => ECHO_BOOL }
 
 C<DEFAULT> Set the default response, optionally.
 
-C<VALID> Ensures the response is valid.  Can be a list or array reference, in which case 
-the values will be presented as a menu.  Alternately, it can be a code ref, where the 
-subroutine is run with C<$_> set to the response.  An invalid response will re-prompt 
+C<VALID> Ensures the response is valid.  Can be a list or array reference, in which case
+the values will be presented as a menu.  Alternately, it can be a code ref, where the
+subroutine is run with C<$_> set to the response.  An invalid response will re-prompt
 the user for input.
 
 C<ECHO_BOOL> Normally (the default 0) text will be echoed as it is typed.  If set to 1
